@@ -15,7 +15,7 @@
 #endif 
 
 #include <ntqframe.h>
-#include <ntqlist.h>
+#include <ntqptrlist.h>
 #include <ntqstring.h>
 
 class TQListView;
@@ -39,8 +39,8 @@ protected:
 	TQString _curMessages;
 };
 
-typedef TQList<KBiffStatusItem>         KBiffStatusList;
-typedef TQListIterator<KBiffStatusItem> KBiffStatusListIterator;
+typedef TQPtrList<KBiffStatusItem>         KBiffStatusList;
+typedef TQPtrListIterator<KBiffStatusItem> KBiffStatusListIterator;
 
 class KBiffStatus : public TQFrame
 {
